@@ -5,7 +5,7 @@ Synopsis: Código baseado na planilha casing do Nakka, disponível em:
     <https://www.nakka-rocketry.net/softw.html#casing>
 Obetivo de transformar a planilha do excel em uma ferramenta em python.
 """
-def main():
+def casing():
     #Chama os pacotes usados no programa
     import math
    # import matplotlib.pyplot  #Necessário somente caso for construir o gráfico, entretanto o gráfico não é necessário
@@ -133,4 +133,4 @@ def main():
     arquivo.close()
 
 #Chamando a definição que o código foi colocado    
-main()
\ No newline at end of file
+casing()
\ No newline at end of file
